@@ -4,8 +4,8 @@ package NetAddr::IP;
 
 use strict;
 #use diagnostics;
-use NetAddr::IP::Lite 1.44 qw(Zero Zeros Ones V4mask V4net);
-use NetAddr::IP::Util 1.46 qw(
+use NetAddr::IP::Lite 1.45 qw(Zero Zeros Ones V4mask V4net);
+use NetAddr::IP::Util 1.47 qw(
 	sub128
 	inet_aton
 	inet_any2n
@@ -27,6 +27,7 @@ use vars qw(
 	@ISA
 	$VERSION
 	$_netlimit
+	$rfc3021
 );
 require Exporter;
 
@@ -35,10 +36,14 @@ require Exporter;
 
 @ISA = qw(Exporter NetAddr::IP::Lite);
 
-$VERSION = do { sprintf " %d.%03d", (q$Revision: 4.61 $ =~ /\d+/g) };
+$VERSION = do { sprintf " %d.%03d", (q$Revision: 4.64 $ =~ /\d+/g) };
+
+$rfc3021 = 0;
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 NetAddr::IP - Manages IPv4 and IPv6 addresses and subnets
@@ -58,6 +63,7 @@ NetAddr::IP - Manages IPv4 and IPv6 addresses and subnets
 	:upper
 	:old_storable
 	:old_nth
+	:rfc3021
   );
 
   NOTE: NetAddr::IP::Util has a full complement of network address
@@ -71,7 +77,7 @@ See L<NetAddr::IP::Util>
 
 
   my $ip = new NetAddr::IP '127.0.0.1';
-	 or if your prefer
+	 or if you prefer
   my $ip = NetAddr::IP->new('127.0.0.1);
 	or from a packed IPv4 address
   my $ip = new_from_aton NetAddr::IP (inet_aton('127.0.0.1'));
@@ -140,18 +146,18 @@ invoked as shown on the next line.
 
 * To set a limit on the size of B<nets> processed or returned by NetAddr::IP.
 
-Set the maximum number of nets beyond which NetAddr::IP will return and
-error as a power of 2 (default 16 or 65536 nets). Each 2**16 consumes approximately 4 megs of
-memory. A 2**20 consumes 64 megs of memory, A 2**24 consumes 1 gigabyte of
-memory.
+Set the maximum number of nets beyond which NetAddr::IP will return
+an error as a power of 2 (default 16 or 65536 nets). Each 2**16
+consumes approximately 4 megs of memory. A 2**20 consumes 64 megs of
+memory, A 2**24 consumes 1 gigabyte of memory.
 
   use NetAddr::IP qw(netlimit);
   netlimit 20;
 
-The maximum B<netlimit> allowed is a 2**24. Attempts to set limits below the
-default of 16 or above the maximum of 24 are ignored.
+The maximum B<netlimit> allowed is 2**24. Attempts to set limits below
+the default of 16 or above the maximum of 24 are ignored.
 
-Returns true on success otherwise undef.
+Returns true on success, otherwise C<undef>.
 
 =cut
 
@@ -174,10 +180,11 @@ Un-tar the distribution in an appropriate directory and type:
 	make test
 	make install
 
-B<NetAddr::IP> depends on B<NetAddr::IP::Util> which installs by default with its primary functions compiled
-using Perl's XS extensions to build a 'C' library. If you do not have a 'C'
-complier available or would like the slower Pure Perl version for some other
-reason, then type:
+B<NetAddr::IP> depends on B<NetAddr::IP::Util> which installs by
+default with its primary functions compiled using Perl's XS extensions
+to build a C library. If you do not have a C complier available or
+would like the slower Pure Perl version for some other reason, then
+type:
 
 	perl Makefile.PL -noxs
 	make
@@ -187,9 +194,9 @@ reason, then type:
 =head1 DESCRIPTION
 
 This module provides an object-oriented abstraction on top of IP
-addresses or IP subnets, that allows for easy manipulations.
-Version 4.xx of NetAdder::IP will work with older
-versions of Perl and is compatible with Math::BigInt.
+addresses or IP subnets that allows for easy manipulations.  Version
+4.xx of NetAddr::IP will work with older versions of Perl and is
+compatible with Math::BigInt.
 
 The internal representation of all IP objects is in 128 bit IPv6 notation.
 IPv4 and IPv6 objects may be freely mixed.
@@ -238,14 +245,14 @@ Will print the string 192.168.1.123/32.
 
 =item B<Equality>
 
-You can test for equality with either C<eq> or C<==>. C<eq> allows the
+You can test for equality with either C<eq> or C<==>. C<eq> allows
 comparison with arbitrary strings as well as NetAddr::IP objects. The
 following example:
 
     if (NetAddr::IP->new('127.0.0.1','255.0.0.0') eq '127.0.0.1/8')
        { print "Yes\n"; }
 
-Will print out "Yes".
+will print out "Yes".
 
 Comparison with C<==> requires both operands to be NetAddr::IP objects.
 
@@ -390,6 +397,11 @@ sub import
         NetAddr::IP::Util::upper();
 	@_ = grep { $_ ne ':upper' } @_;
     }
+    if (grep { $_ eq ':rfc3021' } @_)
+    {
+	$rfc3021 = 1;
+        @_ = grep { $_ ne ':rfc3021' } @_;
+    }
     NetAddr::IP->export_to_level(1, @_);
 }
 
@@ -407,7 +419,8 @@ sub Coalesce {
 
 sub hostenumref($) {
   my $r = _splitref(0,$_[0]);
-  unless ((notcontiguous($_[0]->{mask}))[1] == 128) {
+  unless ((notcontiguous($_[0]->{mask}))[1] == 128 ||
+	  ($rfc3021 && $_[0]->masklen == 31) ) {
     splice(@$r, 0, 1);
     splice(@$r, scalar @$r - 1, 1);
   }
@@ -1092,6 +1105,15 @@ sub hostenum ($) {
 
 Faster version of C<-E<gt>hostenum()>, returning a reference to a list.
 
+NOTE: hostenum and hostenumref report zero (0) useable hosts in a /31
+network. This is the behavior expected prior to RFC 3021. To report 2
+useable hosts for use in point-to-point networks, use B<:rfc3021> tag.
+
+	use NetAddr::IP qw(:rfc3021);
+
+This will cause hostenum and hostenumref to return two (2) useable hosts in
+a /31 network.
+ 
 =item C<$me-E<gt>compact($addr1, $addr2, ...)>
 
 =item C<@compacted_object_list = Compact(@object_list)>
@@ -1536,13 +1558,13 @@ Michael Robinton E<lt>michael@bizsystems.comE<gt>
 
 =head1 WARRANTY
 
-This software comes with the same warranty as perl itself (ie, none),
+This software comes with the same warranty as Perl itself (ie, none),
 so by using it you accept any and all the liability.
 
 =head1 COPYRIGHT
 
 This software is (c) Luis E. Muñoz, 1999 - 2007, and (c) Michael
-Robinton, 2006 - 2011.
+Robinton, 2006 - 2012.
 
 All rights reserved.
 
@@ -1567,9 +1589,9 @@ one.
 You should also have received a copy of the GNU General Public License
 along with this program in the file named "Copying". If not, write to the
 
-        Free Software Foundation, Inc.
-        59 Temple Place, Suite 330
-        Boston, MA  02111-1307, USA
+	Free Software Foundation, Inc.
+	51 Franklin Street, Fifth Floor
+	Boston, MA 02110-1301 USA.
 
 or visit their web page on the internet at:
 
