@@ -32,7 +32,7 @@ use NetAddr::IP::Util qw(
 
 use vars qw(@ISA @EXPORT_OK $VERSION $Accept_Binary_IP $Old_nth $AUTOLOAD *Zero);
 
-$VERSION = do { my @r = (q$Revision: 1.42 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 1.45 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 require Exporter;
 
@@ -574,6 +574,8 @@ To accept addresses in that format, invoke the module as in
 
 If called with no arguments, 'default' is assumed.
 
+If called with an empty string as the argument, returns 'undef'
+
 C<$addr> can be any of the following and possibly more...
 
   n.n
@@ -612,6 +614,8 @@ Any RFC1884 notation
 
 If called with no arguments, 'default' is assumed.
 
+If called with and empty string as the argument, 'undef' is returned;
+
 =cut
 
 my $lbmask = inet_aton('255.0.0.0');
@@ -729,6 +733,9 @@ sub _xnew($$;$$) {
   my $class	= ref $proto || $proto || __PACKAGE__;
   my $ip	= shift;
 
+# fix for bug #75976
+  return undef if defined $ip && $ip eq '';
+
   $ip = 'default' unless defined $ip;
   $ip = _retMBIstring($ip)		# treat as big bcd string
 	if ref $ip && ref $ip eq 'Math::BigInt';	# can /CIDR notation
@@ -1500,6 +1507,7 @@ sub num ($) {
     return 1 unless hasbits($net);	# ipV4/32 or ipV6/128
     $net = $net ^ Ones;
     return 2 unless hasbits($net);	# ipV4/31 or ipV6/127
+    $net &= $_v4net unless $_[0]->{isv6};
     return bin2bcd($net);
   }
 }
@@ -1572,7 +1580,7 @@ so by using it you accept any and all the liability.
 =head1 COPYRIGHT
 
  This software is (c) Luis E. Muoz, 1999 - 2005
- and (c) Michael Robinton, 2006 - 2011.
+ and (c) Michael Robinton, 2006 - 2012.
 
 All rights reserved.
 
@@ -1597,9 +1605,9 @@ one.
 You should also have received a copy of the GNU General Public License
 along with this program in the file named "Copying". If not, write to the
 
-        Free Software Foundation, Inc.
-        59 Temple Place, Suite 330
-        Boston, MA  02111-1307, USA
+        Free Software Foundation, Inc.,
+        51 Franklin Street, Fifth Floor
+        Boston, MA 02110-1301 USA
 
 or visit their web page on the internet at:
 
