@@ -11,7 +11,7 @@ require Exporter;
 
 @ISA = qw(Exporter);
 
-$VERSION = do { my @r = (q$Revision: 0.05 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
+$VERSION = do { my @r = (q$Revision: 0.07 $ =~ /\d+/g); sprintf "%d."."%02d" x $#r, @r };
 
 @EXPORT_OK = qw(
 	inet_aton
@@ -307,11 +307,12 @@ NetAddr::IP::InetBase -- IPv4 and IPV6 utilities
 	AF_INET
 	AF_INET6
 	fake_AF_INET6
+	fillIPv4
   );
 
   use NetAddr::IP::Util qw(:all :inet :ipv4 :ipv6 :math)
 
-  :ipv4	  =>	inet_aton, inet_ntoa
+  :ipv4	  =>	inet_aton, inet_ntoa, fillIPv4
 
   :ipv6	  =>	ipv6_aton, ipv6_ntoa,ipv6_n2x, ipv6_n2d,
 		inet_any2n, inet_n2dx, inet_n2ad
@@ -335,6 +336,7 @@ NetAddr::IP::InetBase -- IPv4 and IPV6 utilities
   $constant = AF_INET();
   $constant = AF_INET6();
   $trueif   = fake_AF_INET6();
+  $ip_filled = fillIPv4($shortIP);
 
   NetAddr::IP::InetBase::lower();
   NetAddr::IP::InetBase::upper();
@@ -743,7 +745,7 @@ Michael Robinton <michael@bizsystems.com>
 
 =head1 COPYRIGHT
 
-Copyright 2003 - 2011, Michael Robinton E<lt>michael@bizsystems.comE<gt>
+Copyright 2003 - 2012, Michael Robinton E<lt>michael@bizsystems.comE<gt>
 
 All rights reserved.
 
@@ -768,9 +770,9 @@ one.
 You should also have received a copy of the GNU General Public License
 along with this program in the file named "Copying". If not, write to the
 
-        Free Software Foundation, Inc.
-        59 Temple Place, Suite 330
-        Boston, MA  02111-1307, USA
+	Free Software Foundation, Inc.,
+	51 Franklin Street, Fifth Floor
+	Boston, MA 02110-1301 USA
 
 or visit their web page on the internet at:
 
